====================
Research Replication
====================

|

To replicate the research run:

.. code:: bash

    # python 3.6 is required by neupy
    git clone https://github.com/sylwekczmil/sevq
    cd sevq
    # create venv and activate
    # up to you

    # install dependencies
    pip3 install -r requirements_research.txt

    # run research code, please ignore warnings, this script can run long time
    python3 run_research.py

